pub fn flight_recorder_count() -> usizeExpand description
Get the current event count without reading event contents.
Returns 0 if init_flight_recorder has not been called.
pub fn flight_recorder_count() -> usizeGet the current event count without reading event contents.
Returns 0 if init_flight_recorder has not been called.