init_flight_recorder

Function init_flight_recorder 

pub fn init_flight_recorder(config: FlightRecorderConfig) -> FlightRecorderLayer
Initialize the global Flight Recorder.

Creates a FlightRecorderLayer and stores the buffer in a global OnceLock so it can be read from anywhere via read_flight_recorder. Returns the layer to add to a tracing subscriber.

If called more than once, the second call’s buffer is not stored globally (the OnceLock is already set), but the returned layer is still independently functional.